@@ -37,9 +37,10 @@
 #define SOFTWARE_CATEGORY_URN_PREFIX "urn:software-category:"
 #define THEME_ICON_URN_PREFIX        "urn:theme-icon:"
 
-static void     miner_applications_finalize                (GObject              *object);
-static void     miner_applications_constructed             (GObject              *object);
-
+static void     miner_applications_initable_iface_init     (GInitableIface       *iface);
+static gboolean miner_applications_initable_init           (GInitable            *initable,
+                                                            GCancellable         *cancellable,
+                                                            GError              **error);
 static gboolean miner_applications_check_file              (TrackerMinerFS       *fs,
                                                             GFile                *file);
 static gboolean miner_applications_check_directory         (TrackerMinerFS       *fs,
@@ -54,6 +55,8 @@ static gboolean miner_applications_process_file_attributes (TrackerMinerFS
                                                             GCancellable         *cancellable);
 static gboolean miner_applications_monitor_directory       (TrackerMinerFS       *fs,
                                                             GFile                *file);
+static void     miner_applications_finalize                (GObject              *object);
+
 
 static GQuark miner_applications_error_quark = 0;
 
@@ -68,7 +71,11 @@ struct ProcessApplicationData {
 	gchar *type;
 };
 
-G_DEFINE_TYPE (TrackerMinerApplications, tracker_miner_applications, TRACKER_TYPE_MINER_FS)
+static GInitableIface* miner_applications_initable_parent_iface;
+
+G_DEFINE_TYPE_WITH_CODE (TrackerMinerApplications, tracker_miner_applications, TRACKER_TYPE_MINER_FS,
+                         G_IMPLEMENT_INTERFACE (G_TYPE_INITABLE,
+                                                miner_applications_initable_iface_init));
 
 static void
 tracker_miner_applications_class_init (TrackerMinerApplicationsClass *klass)
@@ -77,7 +84,6 @@ tracker_miner_applications_class_init (TrackerMinerApplicationsClass *klass)
 	TrackerMinerFSClass *miner_fs_class = TRACKER_MINER_FS_CLASS (klass);
 
 	object_class->finalize = miner_applications_finalize;
-	object_class->constructed = miner_applications_constructed;
 
 	miner_fs_class->check_file = miner_applications_check_file;
 	miner_fs_class->check_directory = miner_applications_check_directory;
@@ -94,33 +100,59 @@ tracker_miner_applications_init (TrackerMinerApplications *ma)
 }
 
 static void
-miner_applications_finalize (GObject *object)
+miner_applications_initable_iface_init (GInitableIface *iface)
 {
-	G_OBJECT_CLASS (tracker_miner_applications_parent_class)->finalize (object);
+	miner_applications_initable_parent_iface = g_type_interface_peek_parent (iface);
+	iface->init = miner_applications_initable_init;
 }
 
-static void
-miner_applications_constructed (GObject *object)
+static gboolean
+miner_applications_initable_init (GInitable     *initable,
+                                  GCancellable  *cancellable,
+                                  GError       **error)
 {
+	TrackerMinerApplications *ma;
+	TrackerMinerFS *fs;
 	GFile *file;
+	GError *inner_error = NULL;
 
-	G_OBJECT_CLASS (tracker_miner_applications_parent_class)->constructed (object);
+	ma = TRACKER_MINER_APPLICATIONS (initable);
+	fs = TRACKER_MINER_FS (initable);
+
+	/* Chain up parent's initable callback before calling child's one */
+	if (!miner_applications_initable_parent_iface->init (initable, cancellable, &inner_error)) {
+		g_propagate_error (error, inner_error);
+		return FALSE;
+	}
 
 	file = g_file_new_for_path ("/usr/share/applications/");
-	tracker_miner_fs_directory_add (TRACKER_MINER_FS (object), file, TRUE);
+	tracker_miner_fs_directory_add (fs, file, TRUE);
 	g_object_unref (file);
 
 	file = g_file_new_for_path ("/usr/share/desktop-directories/");
-	tracker_miner_fs_directory_add (TRACKER_MINER_FS (object), file, TRUE);
+	tracker_miner_fs_directory_add (fs, file, TRUE);
 	g_object_unref (file);
 
 #ifdef HAVE_MEEGOTOUCH
 	file = g_file_new_for_path ("/usr/lib/duicontrolpanel/");
-	tracker_miner_fs_directory_add (TRACKER_MINER_FS (object), file, TRUE);
+	tracker_miner_fs_directory_add (fs, file, TRUE);
 	g_object_unref (file);
+	tracker_miner_applications_meego_init ();
 #endif /* HAVE_MEEGOTOUCH */
 
 	/* FIXME: Check XDG_DATA_DIRS and also process applications in there */
+
+	return TRUE;
+}
+
+static void
+miner_applications_finalize (GObject *object)
+{
+#ifdef HAVE_MEEGOTOUCH
+	tracker_miner_applications_meego_shutdown ();
+#endif /* HAVE_MEEGOTOUCH */
+
+	G_OBJECT_CLASS (tracker_miner_applications_parent_class)->finalize (object);
 }
 
 static void
@@ -720,7 +752,7 @@ miner_applications_process_file (TrackerMinerFS       *fs,
 		G_FILE_ATTRIBUTE_STANDARD_TYPE;
 
 	g_file_query_info_async (file,
-				 attrs,
+	                         attrs,
 	                         G_FILE_QUERY_INFO_NOFOLLOW_SYMLINKS,
 	                         G_PRIORITY_DEFAULT,
 	                         cancellable,
@@ -837,22 +869,28 @@ miner_applications_reset (TrackerMiner *miner)
 	g_object_unref (sparql);
 }
 
-TrackerMiner *
-tracker_miner_applications_new (void)
+gboolean
+tracker_miner_applications_detect_locale_changed (TrackerMiner *miner)
 {
-	TrackerMiner *miner;
+	gboolean changed;
 
-	miner = g_object_new (TRACKER_TYPE_MINER_APPLICATIONS,
-	                      "name", "Applications",
-	                      NULL);
-
-	/* Before returning the newly created miner, check if we need
-	 * to reset it */
-	if (tracker_miner_applications_locale_changed ()) {
+	changed = tracker_miner_applications_locale_changed ();
+	if (changed) {
 		g_message ("Locale change detected, so resetting miner to "
 		           "remove all previously created items...");
 		miner_applications_reset (miner);
 	}
+	return changed;
+}
 
-	return miner;
+TrackerMiner *
+tracker_miner_applications_new (GError **error)
+{
+	return g_initable_new (TRACKER_TYPE_MINER_APPLICATIONS,
+	                       NULL,
+	                       error,
+	                       "name", "Applications",
+	                       "processing-pool-wait-limit", 10,
+	                       "processing-pool-ready-limit", 100,
+	                       NULL);
 }
